@@ -19,27 +19,27 @@ def vector_norm(data, axis=None, out=None):
     np.sqrt(out, out)
     
 
-def get_rot_mat_from_homogeneous(homogeneous_matrix):
+def get_rot_mat_from_homogeneous(h_mat):
     """
     Returns rotation matrix from homogeneous matrix
     """
-    return homogeneous_matrix[:-1, :-1]
+    return h_mat[:-1, :-1]
 
 
-def get_pos_mat_from_homogeneous(homogeneous_matrix):
+def get_pos_mat_from_homogeneous(h_mat):
     """
     Returns position matrix from homogeneous matrix
     """
-    return homogeneous_matrix[:-1,-1]
+    return h_mat[:-1,-1]
 
 
-def get_pose_from_homogeneous(homogeneous_matrix):
+def get_pose_from_homogeneous(h_mat):
     """
     Returns (7,1) pose from homogeneous matrix
     """
-    position = get_pos_mat_from_homogeneous(homogeneous_matrix)
+    position = get_pos_mat_from_homogeneous(h_mat)
     orientation = get_quaternion_from_matrix(
-        get_rot_mat_from_homogeneous(homogeneous_matrix))
+        get_rot_mat_from_homogeneous(h_mat))
     return np.hstack((position, orientation))
 
 
@@ -186,7 +186,30 @@ def get_quaternion_inverse(quaternion):
     return q / np.dot(q, q)
 
 
-def get_homogeneous_matrix_from_quaternion(quaternion):
+def get_quaternion_slerp(qA, qB, t):
+    """
+    referred https://en.wikipedia.org/wiki/Slerp#Quaternion_Slerp
+    """
+    if isinstance(qA, (np.ndarray, list)) and isinstance(qB, (np.ndarray, list)):
+        qA = np.asarray(qA)
+        qB = np.asarray(qB)
+        if qA.shape != (4,):  # quaternion
+            raise ValueError("Expecting the shape of the orientation to be (4,)")
+        if qB.shape == (0,):
+            qB = np.asarray([1.0, 0.0, 0.0, 0.0])
+            
+        a = qB * get_quaternion_inverse(qA)
+        result = np.sign(a) * (np.abs(a)) ** t * qA
+        return result
+
+
+def get_linear_interpoation(postionA, postionB, step):
+    postionA = np.asarray(postionA)
+    postionB = np.asarray(postionB)
+    return postionB * step + postionA * (1 - step)
+    
+
+def get_h_mat_from_quaternion(quaternion):
     """
     Returns homogeneous rotation matrix from quaternion.
     """
@@ -234,7 +257,7 @@ def get_quaternion_about_axis(angle, axis):
     return q
 
 
-def get_homogeneous_matrix(position, orientation):
+def get_h_mat(position=np.zeros(3), orientation=np.array([1.0, 0.0, 0.0, 0.0])):
     """
     Returns homogeneous matrix from position and orientation
     """
@@ -262,7 +285,7 @@ def get_inverse_homogeneous(matrix):
                       np.array([[0, 0, 0, 1]])))
 
 
-def get_identity_homogeneous_matrix():
+def get_identity_h_mat():
     """
     Returns identity matrix
     """
@@ -271,7 +294,7 @@ def get_identity_homogeneous_matrix():
 
 def homogeneous_to_pose(matrix):
     """
-    Returns pose from homogeneous_matrix
+    Returns pose from h_mat
     """
     position = matrix[:3, -1]
     quaternion = get_quaternion_from_matrix(matrix[:3, :3])
@@ -280,11 +303,11 @@ def homogeneous_to_pose(matrix):
 
 def pose_to_homogeneous(pose):
     """
-    Returns homogeneous_matrix from pose
+    Returns h_mat from pose
     """
     pose = np.array(pose).flatten()
     position, orientation = pose[:3], pose[3:]
-    return get_homogeneous_matrix(position=position, orientation=orientation)
+    return get_h_mat(position=position, orientation=orientation)
 
 
 def get_quaternion(orientation, convention='wxyz'):
@@ -337,4 +360,53 @@ def get_rotation_matrix(orientation):
                          "{}".format(orientation.shape))
     else:
         raise TypeError("Expecting the given orientation to be a np.ndarray, quaternion, tuple or list, instead got: "
-                    "{}".format(type(orientation)))
\ No newline at end of file
+                    "{}".format(type(orientation)))
+
+
+def compute_pose_error(target=np.eye(4), result=np.eye(4)):
+    """
+    Computes pose(homogeneous transform) error 
+
+    Args:
+        target_HT (np.array): target homogeneous transform
+        result_HT (np.array): result homogeneous transform 
+
+    Returns:
+        error (np.array)
+    """
+    if  target.shape == (3,) and result.shape == (3,):
+        error = np.linalg.norm(target - result)
+        # target = get_h_mat(position = target)
+        # result = get_h_mat(position = result)
+        return error
+    error = np.linalg.norm(
+        np.dot(result, np.linalg.inv(target)) - np.mat(np.eye(4)))
+    return error
+
+
+def get_transform_to_visual(transform, visual_transform):
+    return np.dot(transform, visual_transform)
+
+
+def change_to_pose(pose_list):
+    if isinstance(pose_list, list):
+        result = np.asarray(pose_list)
+        
+    result = np.zeros(7)
+
+    if len(pose_list) == 7:
+        result = pose_list
+
+    if len(pose_list) == 6:
+        result[0] = pose_list[0]
+        result[1] = pose_list[1]
+        result[2] = pose_list[2]
+        q = get_quaternion(pose_list[3:])
+        result[3] = q[0]
+        result[4] = q[1]
+        result[5] = q[2]
+        result[6] = q[3]
+
+    return result
+
+        
